aboutsummaryrefslogtreecommitdiffstats
path: root/components/script_layout_interface/lib.rs
diff options
context:
space:
mode:
authorBobby Holley <bobbyholley@gmail.com>2016-10-28 14:01:07 -0700
committerBobby Holley <bobbyholley@gmail.com>2016-10-29 14:58:07 -0700
commitbe89f736751d63307c01750f98d5c07a1e940add (patch)
tree6cd08307470e9cc337906794fc853205e7c784e4 /components/script_layout_interface/lib.rs
parent5442fbec3f5a4d00c6cc61adfefc0ae747194db2 (diff)
downloadservo-be89f736751d63307c01750f98d5c07a1e940add.tar.gz
servo-be89f736751d63307c01750f98d5c07a1e940add.zip
Rename NodeData and associated data structures to Element*.
MozReview-Commit-ID: 96VsmsoZtjZ
Diffstat (limited to 'components/script_layout_interface/lib.rs')
-rw-r--r--components/script_layout_interface/lib.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/components/script_layout_interface/lib.rs b/components/script_layout_interface/lib.rs
index 3ad565d0c78..ebef2d20271 100644
--- a/components/script_layout_interface/lib.rs
+++ b/components/script_layout_interface/lib.rs
@@ -53,14 +53,14 @@ use libc::c_void;
use restyle_damage::RestyleDamage;
use std::sync::atomic::AtomicIsize;
use style::atomic_refcell::AtomicRefCell;
-use style::data::NodeData;
+use style::data::ElementData;
pub struct PartialPersistentLayoutData {
/// Data that the style system associates with a node. When the
/// style system is being used standalone, this is all that hangs
/// off the node. This must be first to permit the various
- /// transmutations between NodeData and PersistentLayoutData.
- pub style_data: NodeData,
+ /// transmutations between ElementData and PersistentLayoutData.
+ pub style_data: ElementData,
/// Description of how to account for recent style changes.
pub restyle_damage: RestyleDamage,
@@ -72,7 +72,7 @@ pub struct PartialPersistentLayoutData {
impl PartialPersistentLayoutData {
pub fn new() -> Self {
PartialPersistentLayoutData {
- style_data: NodeData::new(),
+ style_data: ElementData::new(),
restyle_damage: RestyleDamage::empty(),
parallel: DomParallelInfo::new(),
}